function show3dposition_5(cells,shownums,region,showlegend,legendcaptions)
%% Required input is 'cells', an [Nx4] matrix. Columns 1 through 3 of cells specify the x,y and z coordinates of cells of interest im m in respect to a standardized coordinate system. Column 4 of 'cells' specifies the color of the respective cell according to the following list:

if nargin == 1
    showcellnumbers=1;
else
    showcellnumbers=shownums;
end



if region==1 %midbrain
    %Cellscale=3; % avg. cell radius in microns
   Cellscale=2.5; % avg. cell radius in microns
    %Cellscale=2; % avg. cell radius in microns
elseif region==2 %hindbrain
    Cellscale=3; % avg. cell radius in microns
else
end

colors=[...
    0.2 0.2 0.2 % 1 GREY
    0 0 1 % 2 BLUE
    0 1 0 % 3 GREEN (pale)
    1 0 0 % 4 RED
    0 1 1 % 5 CYAN
    1 0 1 % 6 MAGENTA (pale)
    1 1 0 % 7 YELLOW
    0.7 0.7 0.7 % 8 GREY
    0 0 0 % 9 BLACK
   ]; 
    

if ishandle(98)
    close(98)
end
h=figure(98);
set(h,'Units','normalized','Position',[0.2 0.2 0.6 0.6]);
 hold all

if nargin == 5
N=size(legendcaptions,1);
 colormap(colors);
 L = line(ones(N),ones(N), 'LineWidth',3); 
 set(L,{'color'},mat2cell(colors(2:N+1,:),ones(1,N),3));
if showlegend
 legend(legendcaptions,'Location','BestOutside'); 
end
end

%hold on;

if region==1 % generate and plot midbrain landmarks
    
    %plot midline
    [cx cy cz]=cylinder(1);
    midline=surf(cx,-250.*cz,cy);
    set(midline,'FaceAlpha',0.3, 'FaceColor', 'b','EdgeAlpha',0);
    
    %plot AF9 reference
    
    AF9x=([-30 -45 -55 -63 -69 -49 -45 -38 -35 -30; 30 45 55 63 69 49 45 38 35 30]);
    AF9y=([0 -30 -60 -90 -120 -120 -90 -60 -30 0; 0 -30 -60 -90 -120 -120 -90 -60 -30 0]);
    AF9z=([0:-6:-24 -24:6:0 ; 0:-6:-24 -24:6:0]);
    for i=1:2
        h=patch(AF9x(i,:),AF9y(i,:),AF9z(i,:),'w');
        set(h,'edgecolor','k', 'FaceAlpha',0.5, 'EdgeAlpha',0.1);
    end
    %text(-30,0,0,'Test Only - Not actual position of AF9','HorizontalAlignment','center');
    %text(30,0,0,'Test Only - Not actual position of AF9','HorizontalAlignment','center');
    
    % plot OMN reference (blue)
    [OMNx, OMNy, OMNz] = ellipsoid(0,0,0,1,1.5,2.5,20);
    OMNleft=surfl((OMNx*10-10), OMNy*10-182, OMNz*13.6-38);
    OMNright=surfl((OMNx*10+10), OMNy*10-182, OMNz*13.6-38);
    %set([OMNleft,OMNright],'FaceAlpha',0.3, 'FaceColor', 'k','EdgeAlpha',0);
    % modified by FK July 7, 2013.
    set([OMNleft,OMNright],'FaceAlpha',0.2, 'FaceColor', 'k','EdgeAlpha',0);
    
    
    % plot Trochlear nucleus (TRN) reference (green)
    [TRNx, TRNy, TRNz] = ellipsoid(0,0,0,5.2,1.7,1,20);
    TRNleft=surfl((TRNx*7.7-40), TRNy*14.7-180, TRNz*32-1);
    TRNright=surfl((TRNx*7.7+40), TRNy*14.7-180, TRNz*32-1);
    %set([TRNleft,TRNright],'FaceAlpha',0.2, 'FaceColor', 'k','EdgeAlpha',0);
    % modified by FK July 7, 2013.
    set([TRNleft,TRNright],'FaceAlpha',0.1, 'FaceColor', 'k','EdgeAlpha',0);
    
    % plot nucMLF reference (red)
    [nMLF1x, nMLF1y, nMLF1z] = ellipsoid(0,0,0,2.4,2,1,20);
    nMLF1left=surfl((nMLF1x*12.9-33.5), nMLF1y*13.5-158, nMLF1z*20-24);
    nMLF1right=surfl((nMLF1x*12.9+33.5), nMLF1y*13.5-158, nMLF1z*20-24);
    [nMLF2x, nMLF2y, nMLF2z] = ellipsoid(0,0,0,1,1.8,1,20);
    nMLF2left=surfl((nMLF2x*13-14.5), nMLF2y*9.5-147, nMLF2z*9-52);
    nMLF2right=surfl((nMLF2x*13+14.5), nMLF2y*9.5-147, nMLF2z*9-52);
    %set([nMLF1left,nMLF1right,nMLF2left,nMLF2right],'FaceAlpha',0.2, 'FaceColor', 'k','EdgeAlpha',0);
    % modified by FK July 7, 2013.
    set([nMLF1left,nMLF1right,nMLF2left,nMLF2right],'FaceAlpha',0.1, 'FaceColor', 'k','EdgeAlpha',0);
    
elseif region==2 % generate and plot hindbrain landmarks
    
    %plot cones as M-Cell representations
    Cone([-90,0,0] ,[-25,0,0], [0.01, 10],50,'b',1, 0, 0.3);
    Cone([25,0,0] ,[90,0,0], [10,0.01],50,'b',1, 0, 0.3);
    text(-50,0,0,'Mleft');
    text(50,0,0,'Mright');
    
    %plot MLF
    [cx cy cz]=cylinder(1);
    MLF1=surf(cx+3,-250.*cz,cy);
    MLF2=surf(cx-3,-250.*cz,cy);
    set([MLF1 MLF2],'FaceAlpha',0.3, 'FaceColor', 'b','EdgeAlpha',0);
    
    %plot abducens region
    % ABNsize=[120,95,155];
    % ABNoffset=[0,-10,0];
    ABNsize=[120,95,155];
    ABNoffset=[0,-40,0];
    ABNx=([0 1 1 0 0 0.25;1 1 0 0 1 0.75;0.75 0.75 0.25 0.25 1 0.75;0.25 0.75 0.75 0.25 0 0.25]-1)*ABNsize(1)+ABNsize(1)/2+ABNoffset(1);
    ABNy=([0 0 0.9 0.9 0 0.5;0 0.9 0.9 0 0 0.5;0.5 1 1 0.5 0.9 1;0.5 0.5 1 1 0.9 1]-1)*ABNsize(2)+ABNsize(2)/2-40+ABNoffset(2);
    ABNz=([0 0 0 0 0 1;0 0 0 0 0 1;1 1 1 1 0 1;1 1 1 1 0 1]-1)*ABNsize(3)+ABNsize(3)/2+ABNoffset(3);
    for i=1:6
        h=patch(ABNx(:,i),ABNy(:,i),ABNz(:,i),'w');
        set(h,'edgecolor','k', 'FaceAlpha',0.05, 'EdgeAlpha',0.1);
    end
    
end


%plot selected cells

%generate sphere shape as cell representation
[sx sy sz]=sphere(20);
sx=Cellscale.*sx;
sy=Cellscale.*sy;
sz=Cellscale.*sz;

for k=1:size(cells,1)
    if cells(k,4)==0
    else
        h(k)=surf(sx+cells(k,1),sy+cells(k,2),sz+cells(k,3));
        if showcellnumbers==1
            text(cells(k,1),cells(k,2),cells(k,3),num2str(k),'HorizontalAlignment','center');
        end
        set(h(k),'EdgeColor','none', 'FaceColor', colors(cells(k,4),:), 'FaceLighting','phong', ...
            'FaceAlpha',cells(k,5), ...
            'AmbientStrength',0.3, ...
            'DiffuseStrength',0.8, ...
            'SpecularStrength',0.9, ...
            'SpecularExponent',25, ...
            'BackFaceLighting','lit');
    end
end;
camlight left;

%plot axes and reset 3D-view
view(3);
  xlim([-150,150]);
  ylim([-250,75]);
  zlim([-100,100]);
lims = axis;
plot3(lims(1:2),[0 0],[0 0],'color','black') % for x-axis
plot3([0 0],lims(1:2),[0 0],'color','black') % for y-axis
plot3([0 0],[0 0],lims(1:2),'color','black') % for z-axis
box on;
daspect([1 1 1]);

% plot labels
title('3D position of selected cells');
xlabel('x-axis (left to right) [m]');
ylabel('y-axis (caudal to rostral) [m]');
zlabel('z-axis (ventral to dorsal) [m]');