function h_cam=show3dposition_5_131005_with_boundary(cells,shownums,region,showlegend,legendcaptions,if_hide_cell,number_of_colors,cell_number,Alpha_value)
%% Required input is 'cells', an [Nx4] matrix. Columns 1 through 3 of cells specify the x,y and z coordinates of cells of interest im m in respect to a standardized coordinate system. Column 4 of 'cells' specifies the color of the respective cell according to the following list:
% updated by Kun
if nargin == 1
    showcellnumbers=1;
else
    showcellnumbers=shownums;
end



if region==1 %midbrain
    Cellscale=2.5; % avg. cell radius in microns
elseif region==2 %hindbrain
    Cellscale=2.5; % avg. cell radius in microns
else
end

h_color_old=hsv;
h_color_old(21:25,:)=[];
h_color=h_color_old;
max_color=55;
color_step=floor(max_color/(number_of_colors-1));
if ~mod(max_color,(number_of_colors-1))
   color_step=color_step-1;
end
color_index=1:color_step:max_color;
middle_color=h_color(color_index,:);
colors=[[1 1 1]*0.2;middle_color;[0.7 0.7 0.7];[0 0 0]];


if ishandle(98)
    close(98)
end
h=figure(98);
set(h,'Units','normalized','Position',[0.2 0.2 0.6 0.6]);
 hold all

if nargin == 9
   N=size(colors,1)-3;
   colormap(colors);
   L = line(ones(N),ones(N), 'LineWidth',3); 
   set(L,{'color'},mat2cell(colors(2:N+1,:),ones(1,N),3));
   if showlegend
      legend(legendcaptions,'Location','BestOutside'); 
   end
end

%hold on;

if region==1 % generate and plot midbrain landmarks
    
    %plot midline
    [cx, cy, cz]=cylinder(1);
    midline=surf(cx,-250.*cz,cy);
    set(midline,'FaceAlpha',0.3, 'FaceColor', 'b','EdgeAlpha',0);
    
    %plot AF9 reference
    
load('AF9sc.mat')      

for i=1:2
    h=patch(AF9sc{i}(:,1),AF9sc{i}(:,2),AF9sc{i}(:,3),'w');
    set(h,'edgecolor','k', 'FaceAlpha',0.5, 'EdgeAlpha',0.1);
end
    
    % plot OMN reference (blue)
    [OMNx, OMNy, OMNz] = ellipsoid(0,0,0,1,1.5,2.5,20);
    OMNleft=surfl((OMNx*10-10), OMNy*10-167.2-5.17, OMNz*13.6*0.8-48+14.85);
    OMNright=surfl((OMNx*10+10), OMNy*10-167.2-5.17, OMNz*13.6*0.8-48+14.85);
%     set([OMNleft,OMNright],'FaceAlpha',0.3, 'FaceColor', 'b','EdgeAlpha',0);
    set([OMNleft,OMNright],'FaceAlpha',0.1, 'FaceColor', 'k','EdgeAlpha',0);
    
    % plot Trochlear nucleus (TRN) reference (green)
    [TRNx, TRNy, TRNz] = ellipsoid(0,0,0,5.2,1.7,1,20);
    TRNleft=surfl((TRNx*7.7-40), TRNy*14.7-168.5-5.17, TRNz*32-14.1+14.85);
    TRNright=surfl((TRNx*7.7+40), TRNy*14.7-168.5-5.17, TRNz*32-14.1+14.85);
    set([TRNleft,TRNright],'FaceAlpha',0.1, 'FaceColor', 'k','EdgeAlpha',0);
    
    % plot nucMLF reference (red)
    [nMLF1x, nMLF1y, nMLF1z] = ellipsoid(0,0,0,2.4,2,1,20);
    nMLF1left=surfl((nMLF1x*12.9-33.5), nMLF1y*13.5-138.3-5.17, nMLF1z*20-18.3-5+14.85);
    nMLF1right=surfl((nMLF1x*12.9+33.5), nMLF1y*13.5-138.3-5.17, nMLF1z*20-18.3-5+14.85);
    [nMLF2x, nMLF2y, nMLF2z] = ellipsoid(0,0,0,1,1.8,1,20);
    nMLF2left=surfl((nMLF2x*13-14.5), nMLF2y*9.5-126.1-5.17, nMLF2z*9-49.1+14.85);
    nMLF2right=surfl((nMLF2x*13+14.5), nMLF2y*9.5-126.1-5.17, nMLF2z*9-49.1+14.85);
    set([nMLF1left,nMLF1right,nMLF2left,nMLF2right],'FaceAlpha',0.1, 'FaceColor', 'k','EdgeAlpha',0);
    
    
elseif region==2 % generate and plot hindbrain landmarks
    
    %plot cones as M-Cell representations
    Cone([-90,0,0] ,[-25,0,0], [0.01, 10],50,'b',1, 0, 0.3);
    Cone([25,0,0] ,[90,0,0], [10,0.01],50,'b',1, 0, 0.3);
    text(-50,0,0,'Mleft');
    text(50,0,0,'Mright');
    
    %plot MLF
    [cx, cy, cz]=cylinder(1);
    MLF1=surf(cx+3,-250.*cz,cy);
    MLF2=surf(cx-3,-250.*cz,cy);
    set([MLF1 MLF2],'FaceAlpha',0.3, 'FaceColor', 'b','EdgeAlpha',0);
    
    %plot abducens region
    ABNsize=[120,95,155];
    ABNoffset=[0,-40,0];
    ABNx=([0 1 1 0 0 0.25;1 1 0 0 1 0.75;0.75 0.75 0.25 0.25 1 0.75;0.25 0.75 0.75 0.25 0 0.25]-1)*ABNsize(1)+ABNsize(1)/2+ABNoffset(1);
    ABNy=([0 0 0.9 0.9 0 0.5;0 0.9 0.9 0 0 0.5;0.5 1 1 0.5 0.9 1;0.5 0.5 1 1 0.9 1]-1)*ABNsize(2)+ABNsize(2)/2-40+ABNoffset(2);
    ABNz=([0 0 0 0 0 1;0 0 0 0 0 1;1 1 1 1 0 1;1 1 1 1 0 1]-1)*ABNsize(3)+ABNsize(3)/2+ABNoffset(3);
    for i=1:6
        h=patch(ABNx(:,i),ABNy(:,i),ABNz(:,i),'w');
        set(h,'edgecolor','k', 'FaceAlpha',0.05, 'EdgeAlpha',0.1);
    end
    
end


%plot selected cells

%generate sphere shape as cell representation
[sx, sy, sz]=sphere(20);
sx=Cellscale.*sx;
sy=Cellscale.*sy;
sz=Cellscale.*sz;

for k=1:size(cells,1)
    if cells(k,4)==0
    else
        h(k)=surf(sx+cells(k,1),sy+cells(k,2),sz+cells(k,3));
        if showcellnumbers==1
            text(cells(k,1),cells(k,2),cells(k,3),num2str(k),'HorizontalAlignment','center');
        end
        
        if k<=cell_number
            set(h(k),'EdgeColor','none', 'FaceColor', colors(cells(k,4),:), 'FaceLighting','phong', ...
            'FaceAlpha',Alpha_value, 'AmbientStrength',0.3, 'DiffuseStrength',0.8, 'SpecularStrength',0.9, ...
            'SpecularExponent',25, 'BackFaceLighting','lit');
        
            if cells(k,4)==1 && if_hide_cell==1       % if hide the cells
                set(h(k),'FaceAlpha',0)
            end
            if cells(k,4)==14;
                set(h(k),'FaceAlpha',0)
            end
            if ~cells(k,6)                            % hide the cells indicated 'not shoiwn by the user'
                set(h(k),'FaceAlpha',0)
            end
        else
            set(h(k),'EdgeColor','none', 'FaceColor', [0.5 0.5 0.5], 'FaceLighting','phong', ...
            'FaceAlpha',Alpha_value, 'AmbientStrength',0.3, 'DiffuseStrength',0.8, 'SpecularStrength',0.9, ...
            'SpecularExponent',25, 'BackFaceLighting','lit');
        end      

    end
end;

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 
% camlight left;
h_cam = camlight('left');

%plot axes and reset 3D-view
view(3);
  xlim([-150,150]);
  ylim([-250,75]);
  zlim([-100,100]);
lims = axis;
plot3(lims(1:2),[0 0],[0 0],'color','black') % for x-axis
plot3([0 0],lims(1:2),[0 0],'color','black') % for y-axis
plot3([0 0],[0 0],lims(1:2),'color','black') % for z-axis
box on;
daspect([1 1 1]);

% plot labels
xlabel('LR-axis (left to right) [m]');
ylabel('AP-axis (caudal to rostral) [m]');
zlabel('DV-axis (ventral to dorsal) [m]');